@@ -11,9 +11,10 @@ def dtrange(*args):
     else:
         cmp = lambda a, b: a > b
         inc = lambda a: a - step
-    output = [start]
+    #output = [start]
+    output = []
     while cmp(start, stop):
-        start = inc(start)
         output.append(start)
+        start = inc(start)
 
     return output
